part of init;

const _analysisOptionsTemp = '''
include: package:lint/analysis_options.yaml

linter:
  rules:
    avoid_setters_without_getters: false
    avoid_positional_boolean_parameters: false
    sort_pub_dependencies: false
    directives_ordering: false

analyzer:
  errors:
    unused_import: warning

  strong-mode:
    implicit-casts: true
''';

const _cmdCommandsTemp = '''
flutter pub add lint
flutter pub add bot_toast
flutter pub add sizer
flutter pub add get
flutter pub add provider
flutter pub add easy_localization
flutter pub add chaotic
flutter pub get
''';

const _assetsTemp = '''
  
  assets:
    - assets/lang/
''';

const _mainTemp = '''
import 'package:bot_toast/bot_toast.dart';
import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:provider/provider.dart';
import 'package:sizer/sizer.dart';
import 'src/screen/screens.dart';
import 'package:chaotic/commons.dart';
import 'package:easy_logger/easy_logger.dart';

Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();
  await EasyLocalization.ensureInitialized();
  EasyLocalization.logger.enableLevels = [
    LevelMessages.error,
    LevelMessages.warning,
  ];
  Provider.debugCheckInvalidValueType = null;
  preventLandScapeMode();
  
  runApp(
    EasyLocalization(
      supportedLocales: const [
        Locale('en'),
        Locale('ar'),
      ],
      path: 'assets/lang',
      fallbackLocale: const Locale('en'),
      child: MyApp(),
    ),
  );
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Sizer(
      builder: (context, orientation, deviceType) => GetMaterialApp(
        builder: BotToastInit(),
        navigatorObservers: [BotToastNavigatorObserver()],
        localizationsDelegates: context.localizationDelegates,
        supportedLocales: context.supportedLocales,
        locale: context.locale,
        theme: ThemeData(
          pageTransitionsTheme: const PageTransitionsTheme(
            builders: {
              TargetPlatform.android: CupertinoPageTransitionsBuilder(),
              TargetPlatform.iOS: CupertinoPageTransitionsBuilder(),
            },
          ),
        ),
        home: ChangeNotifierProvider.value(
          value: HomeProvider(),
          child: HomeScreen(),
        ),
      ),
    );
  }
}
''';

const _arTemp = '''
{}
''';
const _enTemp = '''
{}
''';

String _newScreenTemp(String screenNameCamelcase) {
  return '''
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import '../screens.dart';


class ${screenNameCamelcase}Screen extends StatelessWidget {
  late ${screenNameCamelcase}Provider provider;
  
  @override
  Widget build(BuildContext context) {
    provider = Provider.of<${screenNameCamelcase}Provider>(context);
    return const Scaffold(
      body: Center(child: Text('hello world, this is $screenNameCamelcase screen')),
    );
  }
}
  ''';
}

String _newProviderTemp(String screenNameCamelcase) {
  return '''
import 'package:flutter/material.dart';

class ${screenNameCamelcase}Provider extends ChangeNotifier{

}
  ''';
}

String _newWidgetTemp(String widgetName) {
  return '''
import 'package:flutter/material.dart';

class $widgetName extends StatelessWidget {

  @override
  Widget build(BuildContext context) {
    return const Padding(
      padding: EdgeInsets.all(8.0),
      child: Text('$widgetName widget'),
    );
  }
}
  ''';
}

String _modelTemp(String modelName) => '''
extension ${modelName.toCamelcase()}Functions on ${modelName.toCamelcase()}{
}
class ${modelName.toCamelcase()}{
}
''';

String _newServiceTemp(String serviceName) {
  return '''
class ${serviceName}Service {
  ${serviceName}Service._();
  static final _instance = ${serviceName}Service._();
  factory ${serviceName}Service.getInstance() => _instance;
  //--------------------
}
  ''';
}

Future<void> _exportNewScreen(String screenName) async {
  final exportTemp = '''
  export '$screenName/$screenName.dart';
  export '$screenName/${screenName}_provider.dart';
''';
  await _screensFile.writeAsString(exportTemp, mode: FileMode.append);
}

Future<void> _exportNewCommon(String commonName) async {
  final exportTemp = '''
  export '$commonName.dart';
''';
  await _commonsFile.writeAsString(exportTemp, mode: FileMode.append);
}

Future<void> _exportNewWidget(String widgetName) async {
  final exportTemp = '''
  export '$widgetName.dart';
''';
  await _widgetsFile.writeAsString(exportTemp, mode: FileMode.append);
}

Future<void> _exportNewModel(String modelName) async {
  final exportTemp = '''
  export '$modelName.dart';
''';
  await _modelsFile.writeAsString(exportTemp, mode: FileMode.append);
}

Future<void> _exportNewService(String serviceName) async {
  final exportTemp = '''
  export '$serviceName.dart';
''';
  await _servicesFile.writeAsString(exportTemp, mode: FileMode.append);
}

String _clearTemp(bool git) => '''
import 'package:chaotic_helper/init.dart';
import 'package:chaotic_helper/backend.dart';

Future<void> main() async {
  ${git ? 'Chaotic.useGit = true;' : ''}
  
  await Chaotic.clear();
}

''';
